# Example for using the Coincidence Counters with python + quTAG
#
# Author: qutools GmbH
# Last edited: Nov 2019
#
# Tested with python 3.7.3 (32bit), numpy-1.13.3 and Windows 7 (64bit)
#
# This is demo code. Use at your own risk. No warranties.
#
# It may be used and modified with no restriction; raw copies as well as 
# modified versions may be distributed without limitation.



# This code shows how to connect with multiple quTAG devices get simple event rates and coincidences via USB.

# Import the python wrapper which wraps the DLL functions. Use the latest wrapper.
# The wrapper should be in the same directory like this code in the folder '..\QUTAG-V1.X.X\userlib\src'.
try:
        import QuTAG
except:
        print("Time Tagger wrapper QuTAG.py is not in the search path.")
import QuTAG
# Initialize the quTAG library, search for devices and connect to each:
# The class "QuTAGmulti" is different to the standard class "QuTAG". Withinn the initialization, the class searches for devices and connects to each of them.
# For additional infos look at the software manual.
qutag = QuTAG.QuTAGmulti()
# The console log shows us the number of found devices, these does not have to be connected.

# Now let's retrieve the most recent values of the built-in coincidence counters from two connected devices. Therefore, we first address one of the devices.
qutag.addressDevice(0)

# All functions after addressing one device are normally called. E.g.:
data,updates = qutag.getCoincCounters()
print("Updates since last call: ", updates, "| Data: ", data)
# updates	Output: Number of data updates by the device since the last call. Pointer may be NULL.
# data	        Output: Counter Values. The array must have at least 31 elements.
#                       The Counters come in the following channel order with single counts and coincidences:
#                       0(5), 1, 2, 3, 4, 1/2, 1/3, 2/3, 1/4, 2/4, 3/4, 1/5, 2/5, 3/5, 4/5, 1/2/3, 1/2/4, 1/3/4, 2/3/4, 1/2/5, 1/3/5, 2/3/5, 1/4/5, 2/4/5, 3/4/5, 1/2/3/4, 1/2/3/5, 1/2/4/5, 1/3/4/5, 2/3/4/5, 1/2/3/4/5 
### see 'tdcbase.h' file reference for more info: function TDC_getCoincCounters(Int32 *data, Int32 *updates)

# Now let's address the second of the devices.
qutag.addressDevice(1)

# Do some stuff..
data,updates = qutag.getCoincCounters()
print("Updates since last call: ", updates, "| Data: ", data)

# Disconnects both connected devices.
qutag.disconnect(0)
qutag.disconnect(1)


